ALL = "All tested clients"

OUTLOOK = "Outlook 2007/10/13"
OUTLOOK_EXPRESS = "Outlook 03/Express/Mail"
OUTLOOK_COM = "Outlook.com"

APPLE_MAIL = "Apple Mail 6.5"
IPHONE = "Iphone iOS 7/iPad"

YAHOO = "Yahoo! Mail"

GMAIL = "Google Gmail"

ANDROID = "Android 4 (Gmail)"
